//-- **** ICC Dilution Calculator | DrNixon.net **** --;
//-- script for antibody dilution calculator --;
//-- Creative Commons by-nc-sa 3.0 license --;
//-- written by Joshua Nixon for use in the Nixon lab --;
//-- feel free to copy and adapt for use in your own lab --;
//-- if you copy as-is please leave this header and other comments in the javascript file --;
//-- Note: Script will only work if this javascript file --;
//-- is included and in the same directory as the html file -  --;
//-- Note: The main window and popup windows use css scripting to format themselves --;
//-- page and popups will look different unless the css file (dilution.css) --;
//-- is also included and in the same directory --;
//-- Change html source if these files are moved to a different location  --;

//-- declare common variables --;

var diluted;
var the_spot;
var title;
var width;
var height;
var window_text;


//-- dilution function --;
//-- alerts user if no number is in the text box --;
//-- alerts user if result is not a number --;
//-- calls popup to warn user if end volume is less than 0.2 ul --;

function diluteIt()
	{
	var the_stock = window.document.dilution.stock.value
	if (the_stock == "")
		{
		alert("Please enter a number");
		}
	var dil_needed = window.document.dilution.needed.value
	if (dil_needed == "")
		{
		alert("Please enter a number");
		}
	var total_volume = window.document.dilution.volume.value
	if (total_volume == "")
		{
		alert("Please enter a number");
		}
	var vol_in_ul = (total_volume*1000)
	diluted = ((dil_needed*vol_in_ul)/the_stock)
	if (diluted == "NaN")
		{
		alert("Please enter a number");
		}
	if (diluted < 0.2)
		{
		undertwoPop();
		}
	window.document.dilution.total.value = diluted
	}

//-- resets all text boxes to the default values --;

function resetIt()
	{
	window.document.dilution.stock.value = "1"
	window.document.dilution.needed.value = "0.0001"
	window.document.dilution.volume.value = "1"
	window.document.dilution.total.value = "0.1"
	window.document.fractions.numerator.value = "1"
	window.document.fractions.denominator.value = "5000"
	window.document.fractions.the_decimal.value = "0.0005";
	window.document.fractions.the_fraction.value = "1/2000";
	}

//-- sets decimal fill-in location and calls fraction calculation --;

function figureStock()
	{
	the_spot = window.document.dilution.stock;
	figureFraction();
	}

//-- sets decimal fill-in location and calls fraction calculation --;

function figureNeeded()
	{
	the_spot = window.document.dilution.needed;
	figureFraction();
	}

//-- calculates decimal from a fraction and fills in text box --;
//-- text box filled in is defined by the two functions above --;

function figureFraction()
	{
	the_top = window.document.fractions.numerator.value;
	the_bottom = window.document.fractions.denominator.value;
	the_fraction = (the_top/the_bottom);
	the_spot.value = the_fraction;
	}

//-- calculates the fraction from a decimal --;
//-- useful when trying to go through someone's notes to duplicate an icc --;
//-- and they don't put in the concentration --;

function getFraction()
	{
	the_number = window.document.fractions.the_decimal.value;
	var this_fraction_bottom = (1/the_number);
	this_fraction = "1/" + this_fraction_bottom;
	window.document.fractions.the_fraction.value = this_fraction;
	}

//-- under 0.2 ul volume warning popup --;
//-- defines variables used in generic popup window function then calls function --;

function undertwoPop()
	{
	title = "Warning!";
	width = 640;
	height = 480;
	window_text = "<h3 class='red center'>Warning!</h3><p>Volumes under 0.2 &micro;L cannot be measured accurately with most pipettors. You will need to increase the dilution of your antibody stock before you can accurately measure out the amount needed.</p>";
	winPop();
	}

//-- how the calculator works explanation popup --;
//-- defines variables used in generic popup window function then calls function --;

function howPop()
	{
	title = "How does this work?";
	width = 640;
	height = 480;
	window_text = "<h3 class='center'>How does this work?</h3><p>This form calculates the dilution of your antibody using the formula:</p><p class='green center' ><strong>C<sub>1</sub>V<sub>1</sub> = C<sub>2</sub>V<sub>2</sub></strong></p><p>C<sub>1</sub> is the concentration of the stock solution, V<sub>1</sub> is the volume of the stock solution needed, C<sub>2</sub> is the desired concentration, and V<sub>2</sub> is the volume of diluted antibody needed. The rest is just math:</p><p class='green center' ><strong>V<sub>1</sub> = C<sub>2</sub>&middot;V<sub>2</sub>/C<sub>1</sub></strong></p>";
	winPop();
	}

//-- help window popup --;
//-- defines variables used in generic popup window function then calls function --;

function helpPop()
	{
	title = "How do I use this?";
	width = 640;
	height = 480;
	window_text = "<h3 class='center'>How do I use this?</h3><p>To use the dilution calculator, just enter in the concentration of the stock solution, the concentration that you want the antibody to be for your reaction, and the total volume of diluted antibody that you need (if you are using 1 mL per tube, just enter the number of tubes you need). For the calculator to work properly, there are a few rules you must follow:</p><ul type='disc'><li>Dilutions need to be entered as decimal numbers, not as fractions. Use the form at the bottom to calculate the decimal from the fraction; hitting &#8220;Stock&#8221; places the decimal in the &#8220;Stock&#8221; box, hitting &#8220;Desired&#8221; fills in the &#8220;Desired&#8221; box.</li><li>When entering numbers in the fraction calculator, don't include commas in large numbers. For example, enter &#8220;10000&#8221; instead of &#8220;10,000&#8221;.</li><li>You cannot accurately pipet volumes less than 0.2 &micro;L. The calculator will warn you if the volume of stock solution you need to add is below 0.2 &micro;L.</li><li>Remember that the calculator will give you the <span class='under'>total volume</span> of stock antibody to add for the proper dilution, <span class='under'>not</span> the amount you will need for each tube.</li><li>To reset the form, hit the &#8220;Reset&#8221; button. All values will be cleared.</li></ul>";
	winPop();
	}

//-- generic popup window script --;
//-- uses variables defined in scripts above to set the following --;
//-- window height, window width, window title --;
//-- popup closes if another window is selected --;

function winPop()
	{
	the_window = window.open("","new","width=" + width + ",height=" + height + ",resizable=yes,scrollbar=auto");
	the_window.window.document.open('text/html');
	the_window.window.document.writeln('<html><title>' + title + '</title>');
	the_window.window.document.writeln('<link rel="stylesheet" type="text/css" href="dilution.css" title="index">'); //-- fix link to css file if location is changed --;
	the_window.window.document.writeln('<body onLoad="focus();" onBlur="close()">');
	the_window.window.document.writeln(window_text);
	the_window.window.document.writeln('<div class="center"><a class="small" href="javascript:close()">(click here to close)</a></div>');
	the_window.window.document.writeln('</body></html>');
	the_window.window.document.close();
	}

